<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 02/28/2009 *
 * ===============                              Last change: 02/28/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : request-functions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Special functions for request handling           *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Spezialle Funktionen fuer die Anfragebehandlung  *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Initialize the request elements
function initRequest () {
	$GLOBALS['raw_request']['get']  = $_GET;
	$GLOBALS['raw_request']['post'] = $_POST;
}

// Wrapper for elements in $_GET
function getRequestElement ($element) {
	// By default no element is there
	$value = null;

	// Is the element cached or there?
	if (isset($GLOBALS['cache_request']['request_get'][$element])) {
		// Then use the cache
		$value = $GLOBALS['cache_request']['request_get'][$element];
	} elseif (isGetRequestElementSet($element)) {
		// Then get it directly
		$value = SQL_ESCAPE($GLOBALS['raw_request']['get'][$element]);

		// Store it in cache
		$GLOBALS['cache_request']['request_get'][$element] = $value;
	} // END - if

	// Return value
	return $value;
}

// Checks if an element in $_GET exists
function isGetRequestElementSet ($element, $subElement = '') {
	if (empty($subElement)) {
		return ((isset($GLOBALS['raw_request']['get'][$element])) && (!empty($GLOBALS['raw_request']['get'][$element])));
	} else {
		return ((isset($GLOBALS['raw_request']['get'][$element][$subElement])) && (!empty($GLOBALS['raw_request']['get'][$element][$subElement])));
	}
}

// Removes an element from $_GET
function unsetGetRequestElement ($element) {
	unset($GLOBALS['raw_request']['get'][$element]);
}

// Getter for whole $_GET array
function getRequestArray () {
	return $GLOBALS['raw_request']['get'];
}

// Counts entries in $_GET or returns false if not an array
function countRequestGet () {
	// By default this is not an array
	$count = false;

	// Get the array
	$GET = getRequestArray();

	// Is it an array?
	if (is_array($GET)) {
		// Then count it
		$count = count($GET);
	} // END - if

	// Return value
}

// Setter for element in $_GET
function setRequestGetElement ($element, $value) {
	// Escape both
	$element = SQL_ESCAPE($element);
	$value   = SQL_ESCAPE($value);

	// Set in $_GET
	$GLOBALS['raw_request']['get'][$element] = $value;

	// Update cache
	$GLOBALS['cache_request']['request_get'][$element][null] = $value;
}

// Wrapper for elements in $_POST
function postRequestElement ($element, $subElement=null) {
	// By default no element is there
	$value = null;

	// Is the element in cache?
	if (isset($GLOBALS['cache_request']['request_post'][$element][$subElement])) {
		// Then use it
		$value = $GLOBALS['cache_request']['request_post'][$element][$subElement];
	} elseif (isPostRequestElementSet($element)) {
		// Then use it
		$value = $GLOBALS['raw_request']['post'][$element];

		// Is $subElement set?
		if ((!is_null($subElement)) && (isPostRequestElementSet($element, $subElement))) {
			// Then use this
			$value = SQL_ESCAPE($value[$subElement]);
		} elseif (!is_array($value)) {
			// Escape it here
			$value = SQL_ESCAPE($value);
		}

		// Set it in cache
		$GLOBALS['cache_request']['request_post'][$element][$subElement] = $value;
	} // END - if

	// Return value
	return $value;
}

// Checks if an element in $_POST exists
function isPostRequestElementSet ($element, $subElement=null) {
	if (is_null($subElement)) {
		return ((isset($GLOBALS['raw_request']['post'][$element])) && (!empty($GLOBALS['raw_request']['post'][$element])));
	} else {
		return ((isset($GLOBALS['raw_request']['post'][$element][$subElement])) && (!empty($GLOBALS['raw_request']['post'][$element][$subElement])));
	}
}

// Removes an element from $_POST
function unsetPostRequestElement ($element) {
	unset($GLOBALS['raw_request']['post'][$element]);
}

// Getter for whole $_POST array
function postRequestArray () {
	return $GLOBALS['raw_request']['post'];
}

// Setter for whole $_POST array
function setPostRequestArray (array $postData) {
	$GLOBALS['raw_request']['post'] = $postData;
}

// Counts entries in $_POST or returns false if not an array
function countRequestPost () {
	// By default this is not an array
	$count = false;

	// Get the array
	$postData = postRequestArray();

	// Is it an array?
	if (is_array($postData)) {
		// Then count it
		$count = count($postData);
	} // END - if

	// Return value
}

// Setter for element in $_POST
function setRequestPostElement ($element, $value) {
	// Is $element or $value an array?
	if (is_array($element)) {
		// Set array
		$eval = "\$GLOBALS['raw_request']['post']['";

		// Add all entries
		$eval .= implode("']['", $element);

		// Finish eval() command
		$eval .= sprintf("'] = \"%s\";", SQL_ESCAPE($value));

		// And run it
		eval($eval);
	} elseif (is_array($value)) {
		// Escape element
		$element = SQL_ESCAPE($element);

		// Value is an array so set it directly
		$GLOBALS['raw_request']['post'][$element] = $value;
	} else {
		// Escape both
		$element = SQL_ESCAPE($element);
		$value   = SQL_ESCAPE($value);

		// Set regular entry
		$GLOBALS['raw_request']['post'][$element] = $value;
	}

	// Update cache
	$GLOBALS['cache_request']['request_post'][$element][null] = $value;
}

// Checks wether a form was sent. If so, the $_POST['ok'] element must be set
function isFormSent () {
	// Simply wrap it!
	return isPostRequestElementSet('ok');
}

// Setter for content type
function setContentType ($contentType) {
	$GLOBALS['content_type'] = (string) $contentType;
}

// Getter for content type
function getContentType () {
	return $GLOBALS['content_type'];
}

// Getter for request URI
function getRequestUri () {
	return $_SERVER['REQUEST_URI'];
}

// [EOF]
?>
